# Taxonomy Development Tools Actions

This repository provides utility actions (such as PURL publishing) for the [Taxonomy Development Tools](https://github.com/brain-bican/taxonomy-development-tools).

## PyPI

[https://pypi.org/project/tdta/](https://pypi.org/project/tdta/)